%define anolis_release 7
%define pkg_version 6.5
%define api_version 0.8.4

%bcond_without minimal

%bcond_without python3

%bcond_with speech_dispatcher

%bcond_with espeak

%bcond_with espeak_ng

%bcond_with ocaml

%{!?tcl_version: %global tcl_version %(echo 'puts $tcl_version' | tclsh)}
%{!?tcl_sitearch: %global tcl_sitearch %{_prefix}/%{_lib}/tcl%{tcl_version}}

# Filter private libraries
%global _privatelibs libbrltty.+\.so.*
%global __provides_exclude ^(%{_privatelibs})$
%global __requires_exclude ^(%{_privatelibs})$

Summary: Braille display driver for Linux/Unix
Name: brltty
Version: %{pkg_version}
Release: %{anolis_release}%{?dist}
License: LGPLv2+
URL: http://brltty.app/
Source0: http://brltty.app/archive/%{name}-%{version}.tar.xz
Source1: brltty.service
Source2: brlapi-config.h
Source3: brlapi-forbuild.h
# # libspeechd.h moved in latest speech-dispatch (NOT sent upstream)
Patch1: brltty-6.3-libspeechd.patch
Patch2: brltty-6.5-add-ru-po-header.patch
BuildRequires: byacc, glibc-kernheaders, bluez-libs-devel, systemd
BuildRequires: gettext, at-spi2-core-devel, alsa-lib-devel
%if %{with espeak}
BuildRequires: espeak-devel
%endif
%if %{with espeak_ng}
BuildRequires: espeak-ng-devel
%endif
BuildRequires: autoconf automake doxygen
BuildRequires: polkit-devel
BuildRequires: libicu-devel
BuildRequires: linuxdoc-tools
BuildRequires: python3-docutils python3-setuptools
Conflicts: brltty-minimal

Requires(post): coreutils
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description
BRLTTY is a background process (daemon) which provides access to the
Linux/Unix console (when in text mode) for a blind person using a
refreshable braille display. It drives the braille display and provides
complete screen review functionality.
%if %{with speech_dispatcher}
BRLTTY can also work with speech synthesizers; if you want to use it with
Speech Dispatcher, please install also package %{name}-speech-dispatcher.

%package speech-dispatcher
Summary: Speech Dispatcher driver for BRLTTY
License: LGPLv2+
BuildRequires: speech-dispatcher-devel
Requires: %{name} = %{pkg_version}-%{release}
%description speech-dispatcher
This package provides the Speech Dispatcher driver for BRLTTY.
%endif

%package docs
Summary: Documentation for BRLTTY
License: LGPLv2+
Requires: %{name} = %{pkg_version}-%{release}
BuildArch: noarch
%description docs
This package provides the documentation for BRLTTY.

%package xw
Summary: XWindow driver for BRLTTY
License: LGPLv2+
BuildRequires: libSM-devel libICE-devel
BuildRequires: libX11-devel libXaw-devel libXext-devel libXt-devel libXtst-devel
Requires: %{name} = %{pkg_version}-%{release}
Requires: xorg-x11-fonts-misc, ucs-miscfixed-fonts

%description xw
This package provides the XWindow driver for BRLTTY.

%package at-spi2
Summary: AtSpi2 driver for BRLTTY
License: LGPLv2+
Requires: %{name} = %{pkg_version}-%{release}

%description at-spi2
This package provides the AtSpi2 driver for BRLTTY.

%if %{with espeak}
%package espeak
Summary: eSpeak driver for BRLTTY
License: LGPLv2+
Requires: %{name} = %{pkg_version}-%{release}
%description espeak
This package provides the eSpeak driver for BRLTTY.
%endif

%if %{with espeak_ng}
%package espeak-ng
Summary: eSpeak-NG driver for BRLTTY
License: LGPLv2+
Requires: %{name} = %{pkg_version}-%{release}
%if %{without espeak}
Obsoletes: brltty-espeak <= 5.6
%endif
%description espeak-ng
This package provides the eSpeak-NG driver for BRLTTY.
%endif

%package -n brlapi
Version: %{api_version}
License: LGPLv2+
Summary: Application Programming Interface for BRLTTY
Recommends: %{name} = %{pkg_version}-%{release}
Requires(pre): glibc-common, shadow-utils
Requires(post): coreutils, util-linux
%description -n brlapi
This package provides the run-time support for the Application
Programming Interface to BRLTTY.

Install this package if you have an application which directly accesses
a refreshable braille display.

%package -n brlapi-devel
Version: %{api_version}
License: LGPLv2+
Requires: brlapi = %{api_version}-%{release}
Summary: Headers, static archive, and documentation for BrlAPI

%description -n brlapi-devel
This package provides the header files, static archive, shared object
linker reference, and reference documentation for BrlAPI (the
Application Programming Interface to BRLTTY).  It enables the
implementation of applications which take direct advantage of a
refreshable braille display in order to present information in ways
which are more appropriate for blind users and/or to provide user
interfaces which are more specifically attuned to their needs.

Install this package if you are developing or maintaining an application
which directly accesses a refreshable braille display.

%package -n tcl-brlapi
Version: %{api_version}
License: LGPLv2+
Requires: brlapi = %{api_version}-%{release}
Conflicts: brlapi < 0.8.4-2
BuildRequires: tcl-devel
Summary: Tcl binding for BrlAPI

%description -n tcl-brlapi
This package provides the Tcl binding for BrlAPI.

%package -n python3-brlapi
%{?python_provide:%python_provide python3-brlapi}
Version: %{api_version}
License: LGPLv2+
Requires: brlapi = %{api_version}-%{release}
BuildRequires: python3-Cython
BuildRequires: python3-devel
Obsoletes:     python2-brlapi < %{api_version}-%{release}
Obsoletes:     python-brlapi < %{api_version}-%{release}
Summary: Python 3 binding for BrlAPI

%description -n python3-brlapi
This package provides the Python 3 binding for BrlAPI.

%package -n brlapi-java
Version: %{api_version}
License: LGPLv2+
Requires: brlapi = %{api_version}-%{release}
BuildRequires: jpackage-utils
BuildRequires: java-devel
Summary: Java binding for BrlAPI

%description -n brlapi-java
This package provides the Java binding for BrlAPI.

%if %{with ocaml}
%package -n ocaml-brlapi
Version: %{api_version}
License: LGPLv2+
Requires: brlapi = %{api_version}-%{release}
BuildRequires: ocaml
BuildRequires: make
Summary: OCaml binding for BrlAPI

%description -n ocaml-brlapi
This package provides the OCaml binding for BrlAPI.
%endif

%package dracut
Summary: brltty module for Dracut
Requires: %{name} = %{pkg_version}-%{release}
Requires: dracut

%description dracut
This package provides brltty module for Dracut.

%if %{with minimal}
%package minimal
Summary: Stripped down brltty version for Anaconda installer
Conflicts: brltty

%description minimal
This package provides stripped down brltty version for Anaconda
installer.
%endif

%define version %{pkg_version}

%prep
%setup -c -a0 -D -T -n %{name}-build
%patch1 -p1 -d %{name}-%{version}
%patch2 -p1 -d %{name}-%{version}
mv %{name}-%{version} python3
%if %{with minimal}
cp -a python3 minimal
%endif


%build
# If MAKEFLAGS=-jN is set it would break local builds.
unset MAKEFLAGS

export CPPFLAGS="-I/usr/lib/jvm/java/include/linux -I/usr/lib/jvm/java/include"

export LDFLAGS="%{?build_ldflags}"
export CFLAGS="%{optflags} -fno-strict-aliasing $LDFLAGS"
export CXXFLAGS="%{optflags} -fno-strict-aliasing $LDFLAGS"

configure_opts=" \
  --disable-stripping \
  --without-curses \
%if %{with speech_dispatcher}
  --with-speechd=%{_prefix} \
%endif
%if %{without espeak}
  --without-espeak \
%else
  --with-espeak \
%endif
  --with-install-root=%{buildroot} \
  JAVA_JAR_DIR=%{_jnidir} \
  JAVA_JNI_DIR=%{_libdir}/brltty \
  JAVA_JNI=yes"

configure_opts_minimal=" \
  --disable-stripping \
  --without-curses \
  --without-speechd \
  --without-espeak \
  --disable-icu \
  --disable-polkit \
  --disable-java-bindings \
  --disable-ocaml-bindings \
  --disable-python-bindings \
  --disable-tcl-bindings \
  --disable-speech-support \
  --without-pcm-package \
  --without-midi-package \
  --with-install-root=%{buildroot} \
  --with-configuration-file=brltty-minimal.conf \
  --with-drivers-directory=%{_libdir}/brltty-minimal \
  --with-tables-directory=%{_sysconfdir}/brltty-minimal \
  --with-scripts-directory=%{_libexecdir}/brltty-minimal \
  JAVA_JNI=no"

export PYTHONCOERCECLOCALE=0

PYTHONS=

%if %{with minimal}
pushd minimal
./autogen
%configure $configure_opts_minimal
%make_build
popd
%endif

pushd python3
./autogen
%configure $configure_opts PYTHON=%{__python3} CYTHON=%{_bindir}/cython
%make_build

# just cd into directory, so it dosen't need a double 'popd'.
cd Documents
%make_build

popd

PYTHONS="$PYTHONS python3"

for python in $PYTHONS
  do pushd $python
    find . -name '*.sgml' |
    while read file; do
       iconv -f iso8859-1 -t utf-8 $file > $file.conv && mv -f $file.conv $file
    done
    find . -name '*.txt' |
    while read file; do
       iconv -f iso8859-1 -t utf-8 $file > $file.conv && mv -f $file.conv $file
    done
    find . -name 'README*' |
    while read file; do
       iconv -f iso8859-1 -t utf-8 $file > $file.conv && mv -f $file.conv $file
    done

    find . \( -path ./doc -o -path ./Documents \) -prune -o \
      \( -name 'README*' -o -name '*.txt' -o -name '*.html' -o \
         -name '*.sgml' -o -name '*.patch' -o \
         \( -path './Bootdisks/*' -type f -perm /ugo=x \) \) -print |
    while read file; do
       mkdir -p ../doc/${file%/*} && cp -rp $file ../doc/$file || exit 1
    done
  popd
done

%install
%if %{with ocaml}
mkdir -p %{buildroot}%{_libdir}/ocaml/stublibs
%endif

%if %{with minimal}
pushd minimal
%make_install

# drop extra drivers
pushd %{buildroot}%{_libdir}/brltty-minimal
rm -f libbrlttybba.so libbrlttybxw.so libbrlttyxa2.so libbrlttysen.so \
  libbrlttyses.so libbrlapi_java.so
popd

# rename brltty to brltty-minimal
mv %{buildroot}%{_bindir}/brltty %{buildroot}%{_bindir}/brltty-minimal

# install config
install -d -m 0755 "%{buildroot}%{_sysconfdir}"
install -p -m 0644 Documents/brltty.conf "%{buildroot}%{_sysconfdir}/brltty-minimal.conf"
popd
%endif

pushd python3
make install JAVA_JAR_DIR=%{_jnidir} \
             JAVA_JNI_DIR=%{_libdir}/brltty \
             JAVA_JNI=yes
popd

pushd python3

pushd Authorization/Polkit
%make_install
popd

install -d -m 0755 "%{buildroot}%{_sysconfdir}" "%{buildroot}%{_mandir}/man5"
install -p -m 0644 Documents/brltty.conf "%{buildroot}%{_sysconfdir}"
echo ".so man1/brltty.1" > %{buildroot}%{_mandir}/man5/brltty.conf.5

install -Dpm 0644 %{SOURCE1} %{buildroot}%{_unitdir}/brltty.service

cp -p LICENSE* ../

rm Documents/Manual-*/*/{*.mk,*.made,Makefile*}
mv Documents/BrlAPIref/{html,BrlAPIref}

for i in Drivers/Speech/SpeechDispatcher/README \
         Documents/ChangeLog Documents/TODO \
         Documents/Manual-BRLTTY \
         Drivers/Braille/XWindow/README \
         Drivers/Braille/XWindow/README \
         Documents/Manual-BrlAPI \
         Documents/BrlAPIref/BrlAPIref \
; do
   mkdir -p ../${i%/*} && cp -rp $i ../$i || exit 1
done

rm -rf %{buildroot}/%{_libdir}/libbrlapi.a

mkdir -p %{buildroot}%{_localstatedir}/lib/brltty

# ghost brlapi.key
touch %{buildroot}%{_sysconfdir}/brlapi.key
chmod 0640 %{buildroot}%{_sysconfdir}/brlapi.key

# disable xbrlapi gdm autostart, there is already orca
rm -f %{buildroot}%{_datadir}/gdm/greeter/autostart/xbrlapi.desktop

chmod 755 %{buildroot}%{_bindir}/brltty-config.sh

# fix multilib
pushd %{buildroot}%{_includedir}/brltty
for f in config forbuild
do
  mv ./$f.h ./$f-$(getconf LONG_BIT).h
done
install -p -m 0644 %{SOURCE2} ./config.h
install -p -m 0644 %{SOURCE3} ./forbuild.h
popd

%find_lang %{name}
install -m 0644 -p %{name}.lang ../

make install-dracut

popd

# drop documentation already instaled by the dracut subpackage
rm -f doc/Initramfs/Dracut/README*
rmdir doc/Initramfs/Dracut doc/Initramfs

%post
%systemd_post brltty.service

%preun
%systemd_preun brltty.service

%postun
%systemd_postun_with_restart brltty.service

%pre -n brlapi
getent group brlapi >/dev/null || groupadd -r brlapi >/dev/null

%post -n brlapi
if [ ! -e %{_sysconfdir}/brlapi.key ]; then
  mcookie > %{_sysconfdir}/brlapi.key
  chgrp brlapi %{_sysconfdir}/brlapi.key
  chmod 0640 %{_sysconfdir}/brlapi.key
fi

%files -f %{name}.lang
%license LICENSE-LGPL
%dir %{_localstatedir}/lib/brltty
%config(noreplace) %{_sysconfdir}/brltty.conf
%{_sysconfdir}/brltty/
%exclude %{_sysconfdir}/brltty/Initramfs
%{_unitdir}/brltty.service
%{_bindir}/brltty
%{_bindir}/brltty-*
%exclude %{_bindir}/brltty-minimal
%{_libdir}/brltty
%exclude %{_libdir}/brltty/libbrlttybba.so
%exclude %{_libdir}/brltty/libbrlttybxw.so
%exclude %{_libdir}/brltty/libbrlttyxa2.so
%if %{with espeak_ng}
%exclude %{_libdir}/brltty/libbrlttysen.so
%endif
%if %{with espeak}
%exclude %{_libdir}/brltty/libbrlttyses.so
%endif
%exclude %{_libdir}/brltty/libbrlapi_java.so
%if %{with speech_dispatcher}
%exclude %{_libdir}/brltty/libbrlttyssd.so
%endif
%doc %{_mandir}/man[15]/brltty.*
%{_sysconfdir}/X11/Xsession.d/90xbrlapi
%{_datadir}/polkit-1/actions/org.a11y.brlapi.policy
%{_datadir}/polkit-1/rules.d/org.a11y.brlapi.rules

%if %{with minimal}
%files minimal -f %{name}.lang
%config(noreplace) %{_sysconfdir}/brltty-minimal.conf
%{_sysconfdir}/brltty-minimal/
%{_bindir}/brltty-minimal
%{_libdir}/brltty-minimal/
%license LICENSE-LGPL
%endif

%if %{with speech_dispatcher}
%files speech-dispatcher
%doc Drivers/Speech/SpeechDispatcher/README
%{_libdir}/brltty/libbrlttyssd.so
%endif

%files docs
%doc Documents/ChangeLog Documents/TODO
%doc Documents/Manual-BRLTTY/
%doc doc/*

%files xw
%doc Drivers/Braille/XWindow/README
%{_libdir}/brltty/libbrlttybxw.so

%files at-spi2
%{_libdir}/brltty/libbrlttyxa2.so

%if %{with espeak}
%files espeak
%{_libdir}/brltty/libbrlttyses.so
%endif

%if %{with espeak_ng}
%files espeak-ng
%{_libdir}/brltty/libbrlttysen.so
%endif

%files -n brlapi
%doc Drivers/Braille/XWindow/README
%doc Documents/Manual-BrlAPI/
%doc %{_mandir}/man1/xbrlapi.*
%doc %{_mandir}/man1/vstp.*
%doc %{_mandir}/man1/eutp.*
%{_bindir}/vstp
%{_bindir}/eutp
%{_bindir}/xbrlapi
%{_libdir}/brltty/libbrlttybba.so
%{_libdir}/libbrlapi.so.*
%ghost %verify(not group) %{_sysconfdir}/brlapi.key

%files -n brlapi-devel
%doc %{_mandir}/man3/brlapi_*.3*
%doc Documents/BrlAPIref/BrlAPIref/
%{_libdir}/libbrlapi.so
%{_includedir}/brltty
%{_includedir}/brlapi*.h
%{_libdir}/pkgconfig/brltty.pc


%files -n tcl-brlapi
%{tcl_sitearch}/brlapi-%{api_version}

%files -n python3-brlapi
%{python3_sitearch}/brlapi.cpython-*.so
%{python3_sitearch}/Brlapi-%{api_version}-*.egg-info

%files -n brlapi-java
%{_libdir}/brltty/libbrlapi_java.so
%{_jnidir}/brlapi.jar

%if %{with ocaml}
%files -n ocaml-brlapi
%{_libdir}/ocaml/brlapi/
%{_libdir}/ocaml/stublibs/
%endif

%files dracut
%{_prefix}/lib/dracut/modules.d/99brltty/
%dir %{_sysconfdir}/brltty/Initramfs
%config(noreplace) %verify(not size md5 mtime) %{_sysconfdir}/brltty/Initramfs/dracut.conf
%config(noreplace) %verify(not size md5 mtime) %{_sysconfdir}/brltty/Initramfs/cmdline

%changelog
* Thu Aug 22 2024 chunchao <chunchao@nfschina.com> - 6.5-7
- Backport ru.po build failed from upstream brltty-6.6

* Mon Mar 11 2024 Bo Ren <rb01097748@alibaba-inc.com> - 6.5-6
- Rebuild with python3.11

* Wed Apr 12 2023 Kun(llfl) <llfl@linux.alibaba.com> - 6.5-2
- optimize spec file

* Sat Mar 25 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 6.5-1
- Strip espeak/espeak-ng/speech-dispatcher sub-package by default

* Mon Dec 05 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 6.5-3
- Bump version to rebuild with icu-72

* Wed Nov 30 2022 Funda Wang <fundawang@yeah.net> - 6.5-2
- Drop duplicate files between brlapi and tcl-brlapi
- Installed /var/lib/brltty directory (rhbz#2042412)

* Tue Nov 29 2022 Funda Wang <fundawang@yeah.net> - 6.5-1
- New version 6.5
- Drop python2 stuff

* Wed Apr 27 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 6.4-2
- Bump version to rebuild with icu-71

* Wed Apr 13 2022 Zhongling He <zhonglingh@linux.alibaba.com> - 6.4-1
- Remove OCaml interface
- Init package from upstream v6.4
